<?php

namespace Drupal\custom_term_cleanup\Form;

use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\taxonomy\Entity\Term;

/**
 * Form for confirming the deletion of taxonomy terms.
 */
class ConfirmDeleteForm extends ConfirmFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'custom_term_cleanup_confirm_delete';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $term_id = NULL) {
    $selected_terms = \Drupal::state()->get('custom_term_cleanup.selected_terms');
    if ($term_id) {
      $terms_to_delete = [$term_id];
    }
    else {
      $terms_to_delete = $selected_terms;
    }

    $this->term_ids = $terms_to_delete;

    $form = parent::buildForm($form, $form_state);

    $form['#title'] = $this->t('Confirm Delete Terms');
    $form['#description'] = $this->t('Are you sure you want to delete the following terms?');

    $terms_list = [];
    foreach ($this->term_ids as $term_id) {
      $term = Term::load($term_id);
      if ($term) {
        $terms_list[] = $term->getName();
      }
    }

    $form['terms'] = [
      '#type' => 'item',
      '#title' => $this->t('Terms to be deleted'),
      '#markup' => implode('<br>', $terms_list),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    return $this->t('Are you sure you want to delete these terms?');
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return new Url('custom_term_cleanup.list_and_confirm_terms');
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    foreach ($this->term_ids as $term_id) {
      $term = Term::load($term_id);
      if ($term) {
        $term->delete();
        $this->messenger()->addMessage($this->t('The term "@name" has been deleted.', ['@name' => $term->getName()]));
      }
    }

    \Drupal::state()->delete('custom_term_cleanup.selected_terms');

    $form_state->setRedirect('custom_term_cleanup.list_and_confirm_terms');
  }

  // Protected $term_ids;.
}
